# zhangTCD - Zhang lab research manage system

Maintain lab records and provide a range of data analysis tools

## Instructions
1. Install:
```
pip install zhangTCD
```

2. Data analysis:
```python
from zhangTCD import xls, raman
```